#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 arch-hs
version:              0.12.1
visibility:           public
id:                   arch-hs-0.12.1-3KWd4zxU58W4VyorUlo555
key:                  arch-hs-0.12.1-3KWd4zxU58W4VyorUlo555
license:              MIT
copyright:            (c) 2020-2022 berberman
maintainer:           berberman <berberman@yandex.com>
author:               berberman
homepage:             https://github.com/berberman/arch-hs
synopsis:             Distribute hackage packages to archlinux
description:
    @arch-hs@ is a command-line program, which simplifies the process of producing
    and maintaining haskell packages for archlinux distribution by automating the
    PKGBUILD generation with the dependency resolving and template filling. Currently,
    @arch-hs@ is unstable, so packagers should not trust it 100%, but always follow the
    <https://wiki.archlinux.org/index.php/Haskell_package_guidelines Haskell package guidelines>.

category:             Distribution
abi:                  e08d021d9007f444bbc7432fd1afd88c
exposed:              True
exposed-modules:
    Distribution.ArchHs.Aur Distribution.ArchHs.Compat
    Distribution.ArchHs.Core Distribution.ArchHs.Exception
    Distribution.ArchHs.ExtraDB Distribution.ArchHs.FilesDB
    Distribution.ArchHs.Hackage Distribution.ArchHs.Internal.Prelude
    Distribution.ArchHs.Local Distribution.ArchHs.Name
    Distribution.ArchHs.Options Distribution.ArchHs.PP
    Distribution.ArchHs.PkgBuild Distribution.ArchHs.PkgDesc
    Distribution.ArchHs.Types Distribution.ArchHs.Utils

hidden-modules:
    Distribution.ArchHs.Internal.NamePresetLoader Paths_arch_hs

import-dirs:          /usr/lib/ghc-9.6.6/site-local/arch-hs-0.12.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/arch-hs-0.12.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/arch-hs-0.12.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/arch-hs
hs-libraries:         HSarch-hs-0.12.1-3KWd4zxU58W4VyorUlo555
extra-libraries:      alpm
include-dirs:         /usr/lib/ghc-9.6.6/site-local/arch-hs-0.12.1/include
depends:
    Cabal-3.10.3.0 Diff-0.5-DbK2KXQffeb9yfLb5gceUe
    aeson-2.2.2.0-E8GnKqfyoqV8B1evVkUtMu
    algebraic-graphs-0.8-51SDmWlHvXWI6yPnEY2qlm
    arch-web-0.3.2-8Xc2hwFW9qHKYVoT7Ybnjt base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-2TgBnHtxRcL45MnFdbw3BB
    conduit-extra-1.3.8-IMQsosV8b6Ffbob12dcl9 containers-0.6.7
    deepseq-1.4.8.1 directory-1.3.8.5 filepath-1.4.300.1
    hackage-db-2.1.3-96nGMzxL9Zh90kgRCwcPxc
    http-client-0.7.19-7npayQWK93786YkcsXS9Bz
    http-client-tls-0.3.6.4-AoMgZkRCYiu1L0w7n4Ap42
    megaparsec-9.7.0-LcQIYWb87vKBQkwIt8CBXH
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-th-0.4.3.17-Kiwz6ZYAlfY2CJ1USHbUAH
    neat-interpolation-0.5.1.4-DvvxM6E8KdU5fPBvtwFa
    optparse-simple-0.1.1.4-HRDptGsk4abDhxkelDzxs5
    polysemy-1.9.2.0-9og9qwLb00vBZnlOeFOyZT
    prettyprinter-1.7.1-EN3LFPJyyjtK4N4FJxxajw
    prettyprinter-ansi-terminal-1.1.3-4nWMmaNgO6x2iiKH85gIMw
    servant-client-0.20.3.0-EDQGPZBiNXW2Z52wKbj86U
    split-0.2.5-9bPPlQ4mlHj6gKeWe5Fjp8
    tar-conduit-0.4.1-D3IRKkOdxO99WrD7bw0oED template-haskell-2.20.0.0
    text-2.0.2

haddock-interfaces:   /usr/share/doc/arch-hs/html/arch-hs.haddock
haddock-html:         /usr/share/doc/arch-hs/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

